summaryrefslogtreecommitdiffstats
path: root/kpdf/ui/pageviewutils.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kpdf/ui/pageviewutils.cpp')
-rw-r--r--kpdf/ui/pageviewutils.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kpdf/ui/pageviewutils.cpp b/kpdf/ui/pageviewutils.cpp
index ce657882..a948d49c 100644
--- a/kpdf/ui/pageviewutils.cpp
+++ b/kpdf/ui/pageviewutils.cpp
@@ -27,7 +27,7 @@ PageViewMessage::PageViewMessage( TQWidget * parent )
setFocusPolicy( TQ_NoFocus );
setBackgroundMode( NoBackground );
setPaletteBackgroundColor(kapp->palette().color(TQPalette::Active, TQColorGroup::Background));
- // if the layout is LtR, we can safely place it in the right position
+ // if the tqlayout is LtR, we can safely place it in the right position
if ( !TQApplication::reverseLayout() )
move( 10, 10 );
resize( 0, 0 );
@@ -54,7 +54,7 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
iconXOffset = 0,
shadowOffset = 1;
// load icon (if set) and update geometry
TQPixmap symbol;
if ( icon != None )
{
@@ -84,44 +84,44 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
width += 2 + symbol.width();
height = TQMAX( height, symbol.height() );
}
- TQRect geometry( 0, 0, width + 10, height + 8 );
+ TQRect tqgeometry( 0, 0, width + 10, height + 8 );
// resize pixmap, mask and widget
static TQBitmap mask;
- mask.resize( geometry.size() );
- m_pixmap.resize( geometry.size() );
- resize( geometry.size() );
+ mask.resize( tqgeometry.size() );
+ m_pixmap.resize( tqgeometry.size() );
+ resize( tqgeometry.size() );
// create and set transparency mask
TQPainter maskPainter( &mask);
mask.fill( TQt::black );
maskPainter.setBrush( TQt::white );
- maskPainter.drawRoundRect( geometry, 1600 / geometry.width(), 1600 / geometry.height() );
+ maskPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
setMask( mask );
// draw background
TQPainter bufferPainter( &m_pixmap );
bufferPainter.setPen( TQt::black );
bufferPainter.setBrush( paletteBackgroundColor() );
- bufferPainter.drawRoundRect( geometry, 1600 / geometry.width(), 1600 / geometry.height() );
+ bufferPainter.drawRoundRect( tqgeometry, 1600 / tqgeometry.width(), 1600 / tqgeometry.height() );
// draw icon if present
if ( !symbol.isNull() )
bufferPainter.drawPixmap( 5 + iconXOffset, 4, symbol, 0, 0, symbol.width(), symbol.height() );
// draw shadow and text
- int yText = geometry.height() - height / 2;
+ int yText = tqgeometry.height() - height / 2;
bufferPainter.setPen( paletteBackgroundColor().dark( 115 ) );
bufferPainter.drawText( 5 + textXOffset + shadowOffset, yText + 1, message );
bufferPainter.setPen( foregroundColor() );
bufferPainter.drawText( 5 + textXOffset, yText, message );
- // if the layout is RtL, we can move it to the right place only after we
+ // if the tqlayout is RtL, we can move it to the right place only after we
// know how much size it will take
if ( TQApplication::reverseLayout() )
- move( parentWidget()->width() - geometry.width() - 10, 10 );
+ move( parentWidget()->width() - tqgeometry.width() - 10, 10 );
- // show widget and schedule a repaint
+ // show widget and schedule a tqrepaint
show();
update();
@@ -168,19 +168,19 @@ int PageViewItem::pageNumber() const
return m_page->number();
}
-const TQRect& PageViewItem::geometry() const
+const TQRect& PageViewItem::tqgeometry() const
{
- return m_geometry;
+ return m_tqgeometry;
}
int PageViewItem::width() const
{
- return m_geometry.width();
+ return m_tqgeometry.width();
}
int PageViewItem::height() const
{
- return m_geometry.height();
+ return m_tqgeometry.height();
}
double PageViewItem::zoomFactor() const
@@ -190,18 +190,18 @@ double PageViewItem::zoomFactor() const
void PageViewItem::setGeometry( int x, int y, int width, int height )
{
- m_geometry.setRect( x, y, width, height );
+ m_tqgeometry.setRect( x, y, width, height );
}
void PageViewItem::setWHZ( int w, int h, double z )
{
- m_geometry.setWidth( w );
- m_geometry.setHeight( h );
+ m_tqgeometry.setWidth( w );
+ m_tqgeometry.setHeight( h );
m_zoomFactor = z;
}
void PageViewItem::moveTo( int x, int y )
{
- m_geometry.moveLeft( x );
- m_geometry.moveTop( y );
+ m_tqgeometry.moveLeft( x );
+ m_tqgeometry.moveTop( y );
}
@@ -54,7 +54,7 @@ void PageViewMessage::display( const TQString & message, Icon icon, int duration
iconXOffset = 0,
shadowOffset = 1;
- // load icon (if set) and update geometry
+ // load icon (if set) and update tqgeometry
TQPixmap symbol;
if ( icon != None )